==> openshift-model-monitoring-5.11.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/ReceiverBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ReceiverBuilder extends io.fabric8.openshift.api.model.monitoring.v1alpha1.ReceiverFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.ReceiverBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1alpha1.Receiver,io.fabric8.openshift.api.model.monitoring.v1alpha1.ReceiverBuilder>{
  public ReceiverBuilder() {
    this(false);
  }
  public ReceiverBuilder(java.lang.Boolean validationEnabled) {
    this(new Receiver(), validationEnabled);
  }
  public ReceiverBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.ReceiverFluent<?> fluent) {
    this(fluent, false);
  }
  public ReceiverBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.ReceiverFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Receiver(), validationEnabled);
  }
  public ReceiverBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.ReceiverFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.Receiver instance) {
    this(fluent, instance, false);
  }
  public ReceiverBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.ReceiverFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.Receiver instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEmailConfigs(instance.getEmailConfigs()); 
    fluent.withName(instance.getName()); 
    fluent.withOpsgenieConfigs(instance.getOpsgenieConfigs()); 
    fluent.withPagerdutyConfigs(instance.getPagerdutyConfigs()); 
    fluent.withPushoverConfigs(instance.getPushoverConfigs()); 
    fluent.withSlackConfigs(instance.getSlackConfigs()); 
    fluent.withVictoropsConfigs(instance.getVictoropsConfigs()); 
    fluent.withWebhookConfigs(instance.getWebhookConfigs()); 
    fluent.withWechatConfigs(instance.getWechatConfigs()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ReceiverBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.Receiver instance) {
    this(instance,false);
  }
  public ReceiverBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.Receiver instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withEmailConfigs(instance.getEmailConfigs()); 
    this.withName(instance.getName()); 
    this.withOpsgenieConfigs(instance.getOpsgenieConfigs()); 
    this.withPagerdutyConfigs(instance.getPagerdutyConfigs()); 
    this.withPushoverConfigs(instance.getPushoverConfigs()); 
    this.withSlackConfigs(instance.getSlackConfigs()); 
    this.withVictoropsConfigs(instance.getVictoropsConfigs()); 
    this.withWebhookConfigs(instance.getWebhookConfigs()); 
    this.withWechatConfigs(instance.getWechatConfigs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1alpha1.ReceiverFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.Receiver build() {
    Receiver buildable = new Receiver(fluent.getEmailConfigs(),fluent.getName(),fluent.getOpsgenieConfigs(),fluent.getPagerdutyConfigs(),fluent.getPushoverConfigs(),fluent.getSlackConfigs(),fluent.getVictoropsConfigs(),fluent.getWebhookConfigs(),fluent.getWechatConfigs());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReceiverBuilder that = (ReceiverBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.2.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/ReceiverBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ReceiverBuilder extends ReceiverFluentImpl<ReceiverBuilder> implements VisitableBuilder<Receiver,ReceiverBuilder>{
  public ReceiverBuilder() {
    this(false);
  }
  public ReceiverBuilder(Boolean validationEnabled) {
    this(new Receiver(), validationEnabled);
  }
  public ReceiverBuilder(ReceiverFluent<?> fluent) {
    this(fluent, false);
  }
  public ReceiverBuilder(ReceiverFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Receiver(), validationEnabled);
  }
  public ReceiverBuilder(ReceiverFluent<?> fluent,Receiver instance) {
    this(fluent, instance, false);
  }
  public ReceiverBuilder(ReceiverFluent<?> fluent,Receiver instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withEmailConfigs(instance.getEmailConfigs()); 
    fluent.withName(instance.getName()); 
    fluent.withOpsgenieConfigs(instance.getOpsgenieConfigs()); 
    fluent.withPagerdutyConfigs(instance.getPagerdutyConfigs()); 
    fluent.withPushoverConfigs(instance.getPushoverConfigs()); 
    fluent.withSlackConfigs(instance.getSlackConfigs()); 
    fluent.withVictoropsConfigs(instance.getVictoropsConfigs()); 
    fluent.withWebhookConfigs(instance.getWebhookConfigs()); 
    fluent.withWechatConfigs(instance.getWechatConfigs()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ReceiverBuilder(Receiver instance) {
    this(instance,false);
  }
  public ReceiverBuilder(Receiver instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withEmailConfigs(instance.getEmailConfigs()); 
    this.withName(instance.getName()); 
    this.withOpsgenieConfigs(instance.getOpsgenieConfigs()); 
    this.withPagerdutyConfigs(instance.getPagerdutyConfigs()); 
    this.withPushoverConfigs(instance.getPushoverConfigs()); 
    this.withSlackConfigs(instance.getSlackConfigs()); 
    this.withVictoropsConfigs(instance.getVictoropsConfigs()); 
    this.withWebhookConfigs(instance.getWebhookConfigs()); 
    this.withWechatConfigs(instance.getWechatConfigs()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ReceiverFluent<?> fluent;
  Boolean validationEnabled;
  public Receiver build() {
    Receiver buildable = new Receiver(fluent.getEmailConfigs(),fluent.getName(),fluent.getOpsgenieConfigs(),fluent.getPagerdutyConfigs(),fluent.getPushoverConfigs(),fluent.getSlackConfigs(),fluent.getVictoropsConfigs(),fluent.getWebhookConfigs(),fluent.getWechatConfigs());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
